@@ -1,6 +1,6 @@
 /*
-Copyright (C) 2000-2002 Jos Roberto B. de A. Monteiro <jrm@autsens.com>
-                        and Pedro Zorzenon Neto <pzn@autsens.com>
+Copyright (C) 2000-2002 Jos Roberto B. de A. Monteiro <jrm@sel.eesc.usp.br>
+                        and Pedro Zorzenon Neto <pzn@vztech.com.br>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@ $Id: mcdelay.h,v 1.2 2003/06/30 17:20:25 pzn Exp $
 #ifndef _MICRODELAY_H
 #define _MICRODELAY_H
 
-void microdelay_init();
+void microdelay_init(int multiply_factor);
 void microdelay(unsigned int microsec);
 
 #endif
